@@ -21,4 +21,7 @@ def config_override(app, config):
 
 @pytest.fixture
 def client(app, config_override):
-    yield TestClient(app)
+    # need a context manager to run startup/shutdown
+    # https://fastapi.tiangolo.com/advanced/testing-events
+    with TestClient(app) as client:
+        yield client
